@@ -15,12 +15,15 @@ $optional_php_exts = array(
     'Multibyte' => 'mbstring',
     'OpenSSL'   => 'openssl',
     'Mcrypt'    => 'mcrypt',
+    'Intl'      => 'intl',
+    'Exif'      => 'exif',
 );
 
 $required_libs = array(
     'PEAR'      => 'PEAR.php',
     'MDB2'      => 'MDB2.php',
     'Net_SMTP'  => 'Net/SMTP.php',
+    'Net_IDNA2' => 'Net/IDNA2.php',
     'Mail_mime' => 'Mail/mime.php',
 );
 
@@ -37,6 +40,8 @@ $ini_checks = array(
     'zend.ze1_compatibility_mode'   => 0,
     'mbstring.func_overload'        => 0,
     'suhosin.session.encrypt'       => 0,
+    'magic_quotes_runtime'          => 0,
+    'magic_quotes_sybase'           => 0,
 );
 
 $optional_checks = array(
@@ -44,20 +49,23 @@ $optional_checks = array(
 );
 
 $source_urls = array(
-    'Sockets' => 'http://www.php.net/manual/en/book.sockets.php',
-    'Session' => 'http://www.php.net/manual/en/book.session.php',
-    'PCRE' => 'http://www.php.net/manual/en/book.pcre.php',
-    'FileInfo' => 'http://www.php.net/manual/en/book.fileinfo.php',
-    'Libiconv' => 'http://www.php.net/manual/en/book.iconv.php',
+    'Sockets'   => 'http://www.php.net/manual/en/book.sockets.php',
+    'Session'   => 'http://www.php.net/manual/en/book.session.php',
+    'PCRE'      => 'http://www.php.net/manual/en/book.pcre.php',
+    'FileInfo'  => 'http://www.php.net/manual/en/book.fileinfo.php',
+    'Libiconv'  => 'http://www.php.net/manual/en/book.iconv.php',
     'Multibyte' => 'http://www.php.net/manual/en/book.mbstring.php',
-    'Mcrypt' => 'http://www.php.net/manual/en/book.mcrypt.php',
-    'OpenSSL' => 'http://www.php.net/manual/en/book.openssl.php',
-    'JSON' => 'http://www.php.net/manual/en/book.json.php',
-    'DOM' => 'http://www.php.net/manual/en/book.dom.php',
-    'PEAR' => 'http://pear.php.net',
-    'MDB2' => 'http://pear.php.net/package/MDB2',
-    'Net_SMTP' => 'http://pear.php.net/package/Net_SMTP',
+    'Mcrypt'    => 'http://www.php.net/manual/en/book.mcrypt.php',
+    'OpenSSL'   => 'http://www.php.net/manual/en/book.openssl.php',
+    'JSON'      => 'http://www.php.net/manual/en/book.json.php',
+    'DOM'       => 'http://www.php.net/manual/en/book.dom.php',
+    'Intl'      => 'http://www.php.net/manual/en/book.intl.php',
+    'Exif'      => 'http://www.php.net/manual/en/book.exif.php',
+    'PEAR'      => 'http://pear.php.net',
+    'MDB2'      => 'http://pear.php.net/package/MDB2',
+    'Net_SMTP'  => 'http://pear.php.net/package/Net_SMTP',
     'Mail_mime' => 'http://pear.php.net/package/Mail_mime',
+    'Net_IDNA2' => 'http://pear.php.net/package/Net_IDNA2',
 );
 
 echo '<input type="hidden" name="_step" value="' . ($RCI->configured ? 3 : 2) . '" />';
@@ -66,7 +74,7 @@ echo '<input type="hidden" name="_step" value="' . ($RCI->configured ? 3 : 2) .
 <h3>Checking PHP version</h3>
 <?php
 
-define('MIN_PHP_VERSION', '5.2.0');
+define('MIN_PHP_VERSION', '5.2.1');
 if (version_compare(PHP_VERSION, MIN_PHP_VERSION, '>=')) {
     $RCI->pass('Version', 'PHP ' . PHP_VERSION . ' detected');
 } else {
