@@ -5,8 +5,11 @@
  | program/include/rcube_plugin.php                                      |
  |                                                                       |
  | This file is part of the Roundcube Webmail client                     |
- | Copyright (C) 2008-2009, Roundcube Dev. - Switzerland                 |
- | Licensed under the GNU GPL                                            |
+ | Copyright (C) 2008-2009, The Roundcube Dev Team                       |
+ |                                                                       |
+ | Licensed under the GNU General Public License version 3 or            |
+ | any later version with exceptions for skins & plugins.                |
+ | See the README file for a full license statement.                     |
  |                                                                       |
  | PURPOSE:                                                              |
  |  Abstract plugins interface/class                                     |
@@ -15,7 +18,7 @@
  | Author: Thomas Bruederli <roundcube@gmail.com>                        |
  +-----------------------------------------------------------------------+
 
- $Id: rcube_plugin.php 3989 2010-09-25 13:03:53Z alec $
+ $Id$
 
 */
 
@@ -26,34 +29,82 @@
  */
 abstract class rcube_plugin
 {
+  /**
+   * Class name of the plugin instance
+   *
+   * @var string
+   */
   public $ID;
+
+  /**
+   * Instance of Plugin API
+   *
+   * @var rcube_plugin_api
+   */
   public $api;
+
+  /**
+   * Regular expression defining task(s) to bind with 
+   *
+   * @var string
+   */
   public $task;
+
+  /**
+   * Disables plugin in AJAX requests
+   *
+   * @var boolean
+   */
+  public $noajax = false;
+
+  /**
+   * Disables plugin in framed mode
+   *
+   * @var boolean
+   */
+  public $noframe = false;
+
   protected $home;
   protected $urlbase;
   private $mytask;
 
+
   /**
    * Default constructor.
+   *
+   * @param rcube_plugin_api $api Plugin API
    */
   public function __construct($api)
   {
     $this->ID = get_class($this);
     $this->api = $api;
-    $this->home = $api->dir . DIRECTORY_SEPARATOR . $this->ID;
+    $this->home = $api->dir . $this->ID;
     $this->urlbase = $api->url . $this->ID . '/';
   }
-  
+
   /**
    * Initialization method, needs to be implemented by the plugin itself
    */
   abstract function init();
-  
+
+
+  /**
+   * Attempt to load the given plugin which is required for the current plugin
+   *
+   * @param string Plugin name
+   * @return boolean True on success, false on failure
+   */
+  public function require_plugin($plugin_name)
+  {
+    return $this->api->load_plugin($plugin_name);
+  }
+
+
   /**
    * Load local config file from plugins directory.
    * The loaded values are patched over the global configuration.
    *
-   * @param string Config file name relative to the plugin's folder
+   * @param string $fname Config file name relative to the plugin's folder
    * @return boolean True on success, false on failure
    */
   public function load_config($fname = 'config.inc.php')
@@ -66,40 +117,87 @@ abstract class rcube_plugin
         'message' => "Failed to load config from $fpath"), true, false);
       return false;
     }
-    
+
     return true;
   }
 
   /**
    * Register a callback function for a specific (server-side) hook
    *
-   * @param string Hook name
-   * @param mixed Callback function as string or array with object reference and method name
+   * @param string $hook Hook name
+   * @param mixed  $callback Callback function as string or array with object reference and method name
    */
   public function add_hook($hook, $callback)
   {
     $this->api->register_hook($hook, $callback);
   }
-  
+
+  /**
+   * Unregister a callback function for a specific (server-side) hook.
+   *
+   * @param string $hook Hook name
+   * @param mixed  $callback Callback function as string or array with object reference and method name
+   */
+  public function remove_hook($hook, $callback)
+  {
+    $this->api->unregister_hook($hook, $callback);
+  }
+
   /**
    * Load localized texts from the plugins dir
    *
-   * @param string Directory to search in
-   * @param mixed Make texts also available on the client (array with list or true for all)
+   * @param string $dir Directory to search in
+   * @param mixed  $add2client Make texts also available on the client (array with list or true for all)
    */
   public function add_texts($dir, $add2client = false)
   {
     $domain = $this->ID;
-    
-    $lang = $_SESSION['language'];
+    $lang   = $_SESSION['language'];
+    $langs  = array_unique(array('en_US', $lang));
     $locdir = slashify(realpath(slashify($this->home) . $dir));
-    $texts = array();
-    
-    foreach (array('en_US', $lang) as $lng) {
-      @include($locdir . $lng . '.inc');
-      $texts = (array)$labels + (array)$messages + (array)$texts;
+    $texts  = array();
+
+    // Language aliases used to find localization in similar lang, see below
+    $aliases = array(
+        'de_CH' => 'de_DE',
+        'es_AR' => 'es_ES',
+        'fa_AF' => 'fa_IR',
+        'nl_BE' => 'nl_NL',
+        'pt_BR' => 'pt_PT',
+        'zh_CN' => 'zh_TW',
+    );
+
+    // use buffering to handle empty lines/spaces after closing PHP tag
+    ob_start();
+
+    foreach ($langs as $lng) {
+      $fpath = $locdir . $lng . '.inc';
+      if (is_file($fpath) && is_readable($fpath)) {
+        include $fpath;
+        $texts = (array)$labels + (array)$messages + (array)$texts;
+      }
+      else if ($lng != 'en_US') {
+        // Find localization in similar language (#1488401)
+        $alias = null;
+        if (!empty($aliases[$lng])) {
+          $alias = $aliases[$lng];
+        }
+        else if ($key = array_search($lng, $aliases)) {
+          $alias = $key;
+        }
+
+        if (!empty($alias)) {
+          $fpath = $locdir . $alias . '.inc';
+          if (is_file($fpath) && is_readable($fpath)) {
+            include $fpath;
+            $texts = (array)$labels + (array)$messages + (array)$texts;
+          }
+        }
+      }
     }
 
+    ob_end_clean();
+
     // prepend domain to text keys and add to the application texts repository
     if (!empty($texts)) {
       $add = array();
@@ -108,7 +206,7 @@ abstract class rcube_plugin
 
       $rcmail = rcmail::get_instance();
       $rcmail->load_language($lang, $add);
-      
+
       // add labels to client
       if ($add2client) {
         $js_labels = is_array($add2client) ? array_map(array($this, 'label_map_callback'), $add2client) : array_keys($add);
@@ -116,10 +214,11 @@ abstract class rcube_plugin
       }
     }
   }
-  
+
   /**
    * Wrapper for rcmail::gettext() adding the plugin ID as domain
    *
+   * @param string $p Message identifier
    * @return string Localized text
    * @see rcmail::gettext()
    */
@@ -131,7 +230,7 @@ abstract class rcube_plugin
   /**
    * Register this plugin to be responsible for a specific task
    *
-   * @param string Task name (only characters [a-z0-9_.-] are allowed)
+   * @param string $task Task name (only characters [a-z0-9_.-] are allowed)
    */
   public function register_task($task)
   {
@@ -144,8 +243,8 @@ abstract class rcube_plugin
     *
     * The callback will be executed upon a request like /?_task=mail&_action=plugin.myaction
     *
-    * @param string Action name (should be unique)
-    * @param mixed Callback function as string or array with object reference and method name
+    * @param string $action  Action name (should be unique)
+    * @param mixed $callback Callback function as string or array with object reference and method name
    */
   public function register_action($action, $callback)
   {
@@ -158,8 +257,8 @@ abstract class rcube_plugin
    * When parsing a template for display, tags like <roundcube:object name="plugin.myobject" />
    * will be replaced by the return value if the registered callback function.
    *
-   * @param string Object name (should be unique and start with 'plugin.')
-   * @param mixed Callback function as string or array with object reference and method name
+   * @param string $name Object name (should be unique and start with 'plugin.')
+   * @param mixed  $callback Callback function as string or array with object reference and method name
    */
   public function register_handler($name, $callback)
   {
@@ -169,7 +268,7 @@ abstract class rcube_plugin
   /**
    * Make this javascipt file available on the client
    *
-   * @param string File path; absolute or relative to the plugin directory
+   * @param string $fn File path; absolute or relative to the plugin directory
    */
   public function include_script($fn)
   {
@@ -179,18 +278,18 @@ abstract class rcube_plugin
   /**
    * Make this stylesheet available on the client
    *
-   * @param string File path; absolute or relative to the plugin directory
+   * @param string $fn File path; absolute or relative to the plugin directory
    */
   public function include_stylesheet($fn)
   {
     $this->api->include_stylesheet($this->resource_url($fn));
   }
-  
+
   /**
    * Append a button to a certain container
    *
-   * @param array Hash array with named parameters (as used in skin templates)
-   * @param string Container name where the buttons should be added to
+   * @param array $p Hash array with named parameters (as used in skin templates)
+   * @param string $container Container name where the buttons should be added to
    * @see rcube_remplate::button()
    */
   public function add_button($p, $container)
@@ -200,16 +299,16 @@ abstract class rcube_plugin
       foreach (array('imagepas', 'imageact', 'imagesel') as $key)
         if ($p[$key])
           $p[$key] = $this->api->url . $this->resource_url($p[$key]);
-      
+
       $this->api->add_content($this->api->output->button($p), $container);
     }
   }
-  
+
   /**
    * Generate an absolute URL to the given resource within the current
    * plugin directory
    *
-   * @param string The file name
+   * @param string $fn The file name
    * @return string Absolute URL to the given resource
    */
   public function url($fn)
@@ -219,6 +318,8 @@ abstract class rcube_plugin
 
   /**
    * Make the given file name link into the plugin directory
+   *
+   * @param string $fn Filename
    */
   private function resource_url($fn)
   {
@@ -227,16 +328,16 @@ abstract class rcube_plugin
     else
       return $fn;
   }
-  
+
   /**
    * Provide path to the currently selected skin folder within the plugin directory
    * with a fallback to the default skin folder.
    *
    * @return string Skin path relative to plugins directory
    */
-  protected function local_skin_path()
+  public function local_skin_path()
   {
-      $skin_path = 'skins/'.$this->api->output->config['skin'];
+      $skin_path = 'skins/'.$this->api->config->get('skin');
       if (!is_dir(realpath(slashify($this->home) . $skin_path)))
         $skin_path = 'skins/default';
     return $skin_path;
@@ -244,12 +345,13 @@ abstract class rcube_plugin
 
   /**
    * Callback function for array_map
+   *
+   * @param string $key Array key.
+   * @return string
    */
   private function label_map_callback($key)
   {
     return $this->ID.'.'.$key;
   }
 
-
 }
-
